<?php
// ==================================================================
// Theme scripts
// ==================================================================
function onenine3_theme_scripts(){
  wp_enqueue_style( 'onenine3-style', get_stylesheet_uri(), null, array(), 'all' );
  if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) wp_enqueue_script( 'comment-reply' );
  wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/js/fitvids.js', array( 'jquery' ), '1.0', true );
  wp_enqueue_script( 'doubletaptogo', get_template_directory_uri() . '/js/doubletaptogo.js', array( 'jquery' ), null, true );
  wp_enqueue_script( 'tinynav', get_template_directory_uri() . '/js/tinynav.js', array( 'jquery' ), null, true );
  wp_enqueue_script( 'onenine3-scripts', get_template_directory_uri() . '/js/scripts.js', array( 'jquery' ), null, true );
}
add_action( 'wp_enqueue_scripts', 'onenine3_theme_scripts' );

// ==================================================================
// Conditional scripts
// ==================================================================
function onenine3_conditional_scripts() {
  ?>
  <!--[if lt IE 9]><script src="<?php echo get_template_directory_uri(); ?>/js/html5.js" type="text/javascript"></script><![endif]-->
  <?php
}
add_action( 'wp_head', 'onenine3_conditional_scripts' );

// ==================================================================
// WordPress dashicons
// ==================================================================
function onenine3_load_dashicons_front_end() {
  wp_enqueue_style( 'dashicons' );
}
add_action( 'wp_enqueue_scripts', 'onenine3_load_dashicons_front_end' );

// ==================================================================
// Mobile menu
// ==================================================================
function onenine3_mobile_menu_scripts() {

if( function_exists( 'wp_add_inline_script' ) ) {

  wp_register_script( 'tinynav', get_template_directory_uri() . '/js/tinynav.js', array( 'jquery' ), null, true );
  // out extra script stuff
  $output = "jQuery( document ).ready( function( $ ){";
  $output .= "$( 'nav.nav .menu ul' ).tinyNav({";
  $output .= "header: 'Menu',";
  $output .= "active: 'current_page_item, current-menu-item'";
  $output .= "});";
  $output .= "});";
  wp_add_inline_script( 'tinynav', $output );

} else { ?>

  <script type="text/javascript">
  /* <![CDATA[ */
  jQuery( document ).ready( function( $ ){ // START
    // Mobile menu
    $( 'nav.nav .menu ul' ).tinyNav({
      header: '<?php _e( 'Menu', 'onenine3' ); ?>',
      active: 'current_page_item, current-menu-item'
    });
  }); // END
  /* ]]> */
  </script>

<?php }

}
add_action( 'wp_footer', 'onenine3_mobile_menu_scripts' );

// Theme Setup
// ====================================================================================================================================
function onenine3_theme_setup() {
// ====================================================================================================================================

  // ==================================================================
  // Language
  // ==================================================================
  load_theme_textdomain( 'onenine3', get_template_directory() . '/languages' );

  // ==================================================================
  // Post thumbnail
  // ==================================================================
  add_theme_support( 'post-thumbnails' );

  // ==================================================================
  // Add default posts and comments RSS feed links to head
  // ==================================================================
  add_theme_support( 'automatic-feed-links' );

  // ==================================================================
  // Menu location
  // ==================================================================
  register_nav_menu( 'top_menu', __( 'Top Menu', 'onenine3' ) );

  // ==================================================================
  // Custom background
  // ==================================================================
  add_theme_support( 'custom-background', array( 'default-color' => 'efefef' ) );

  // ==================================================================
  // Visual editor stylesheet
  // ==================================================================
  add_editor_style( 'editor.css' );

  // ==================================================================
  // Header title tag support
  // ==================================================================
  add_theme_support( 'title-tag' );

  // ==================================================================
  // HTML5 Support
  // ==================================================================
	add_theme_support( 'html5', array(
    'search-form',
    'comment-form',
    'comment-list',
    'gallery',
    'caption',
	) );

  // ==================================================================
  // Content width
  // ==================================================================
  if ( ! isset( $content_width ) )
    $content_width = 580;
      function onenine3_set_full_width() {
        global $full_width;
        if ( is_page_template( 'full-page.php' ) || is_page_template( 'full-title-page.php' ) )
        $full_width = 960;
      }
  add_action( 'template_redirect', 'onenine3_set_full_width' );

// Theme Setup
// ====================================================================================================================================
}
add_action( 'after_setup_theme', 'onenine3_theme_setup' );
// ====================================================================================================================================

// ==================================================================
// WordPress header title backward compatibility
// ==================================================================
if ( ! function_exists( '_wp_render_title_tag' ) ) :
  function onenine3_theme_render_title() {
  echo wp_title();
  }
  add_action( 'wp_head', 'onenine3_theme_render_title' );
endif;

// ==================================================================
// Post/page pagination
// ==================================================================
function onenine3_get_link_pages() {
  wp_link_pages(
    array(
    'before'           => '<p class="page-pagination"><span class="page-pagination-title">' . __( 'Pages:', 'onenine3' ) . '</span>',
    'after'            => '</p>',
    'link_before'      => '<span class="page-pagination-number">',
    'link_after'       => '</span>',
    'next_or_number'   => 'number',
    'nextpagelink'     => __( 'Next page', 'onenine3' ),
    'previouspagelink' => __( 'Previous page', 'onenine3' ),
    'pagelink'         => '%',
    'echo'             => 1
    )
  );
}

// ==================================================================
// Pagination (WordPress)
// ==================================================================
function onenine3_get_pagination_links() {
  the_posts_pagination( array(
    'mid_size'  => 5,
    'prev_text' => __( 'Previous page', 'onenine3' ),
    'next_text' => __( 'Next page', 'onenine3' ),
  ) );
}

// ==================================================================
// Widget - Sidebar
// ==================================================================
function onenine3_right_widgets_init() {
  register_sidebar( array(
    'name'          => __( 'Right Widget', 'onenine3' ),
    'id'            => 'right-widget',
    'class'         => '',
    'description'   => 'Right side widget area',
    'before_widget' => '<article class="side-widget %2$s" id="%1$s">',
    'after_widget'  => '</article>',
    'before_title'  => '<h3>',
    'after_title'   => '</h3>',
  ) );
}
add_action( 'widgets_init', 'onenine3_right_widgets_init' );